@@ -38,60 +38,26 @@
 #define _(String) dgettext (PACKAGE, String)
 
 static guint g_tid;
-static PurplePlugin *g_plugin;
-static gboolean g_run=1;
+static gboolean g_run = 0;
 static struct TrackInfo mostrecent_ti;
 static PurpleCmdId cmdid_nowplaying;
 static PurpleCmdId cmdid_np;
 
 //--------------------------------------------------------------------
 
-#ifndef WIN32
-gboolean get_amarok_info(struct TrackInfo* ti);
-gboolean get_xmms_info(struct TrackInfo* ti);
-gboolean get_audacious_legacy_info(struct TrackInfo* ti);
-gboolean get_audacious_info(struct TrackInfo* ti);
-gboolean get_rhythmbox_info(struct TrackInfo* ti);
-gboolean get_exaile_info(struct TrackInfo* ti);
-gboolean get_banshee_info(struct TrackInfo* ti);
-gboolean get_quodlibet_info(struct TrackInfo* ti);
-gboolean get_listen_info(struct TrackInfo* ti);
-gboolean get_xmms2_info(struct TrackInfo* ti);
-gboolean get_squeezecenter_info(struct TrackInfo* ti);
-gboolean get_mpris_info(struct TrackInfo* ti);
-gboolean get_dbusbird_info(struct TrackInfo* ti);
-
-void get_xmmsctrl_pref(GtkBox *box);
-void get_xmms2_pref(GtkBox *box);
-void get_squeezecenter_pref(GtkBox *box);
-
-#else
-gboolean get_foobar2000_info(struct TrackInfo* ti);
-gboolean get_winamp_info(struct TrackInfo* ti);
-gboolean get_wmp_info(struct TrackInfo* ti);
-gboolean get_itunes_info(struct TrackInfo* ti);
-gboolean get_msn_compat_info(struct TrackInfo *ti);
-
-void get_msn_compat_pref(GtkBox *box);
-#endif
-
-gboolean get_mpd_info(struct TrackInfo* ti);
-gboolean get_lastfm_info(struct TrackInfo* ti);
-
-void get_mpd_pref(GtkBox *box);
-void get_lastfm_pref(GtkBox *box);
-
 // Global array of players
 struct PlayerInfo g_players[] = {
 #ifndef WIN32
 	{ "XMMS", get_xmms_info, get_xmmsctrl_pref },
 	{ "Audacious < 1.4", get_audacious_legacy_info, get_xmmsctrl_pref },
 	{ "Audacious >= 1.4", get_audacious_info, 0 },
-	{ "Amarok", get_amarok_info, 0 },
+	{ "Amarok 1.x.x", get_amarok_info, 0 },
 	{ "Rhythmbox", get_rhythmbox_info, 0 },
 	{ "Banshee", get_banshee_info, 0 },
+	{ "Vagalume", get_vagalume_info, 0 },
 	{ "QuodLibet", get_quodlibet_info, 0 },
 	{ "Exaile", get_exaile_info, 0 },
+	{ "MOC", get_moc_info, 0 },
 	{ "Listen", get_listen_info, 0 },
 	{ "SqueezeCenter", get_squeezecenter_info, get_squeezecenter_pref },
 #ifdef HAVE_XMMSCLIENT
@@ -103,11 +69,12 @@ struct PlayerInfo g_players[] = {
 	{ "Winamp", get_winamp_info, 0 },
 	{ "Windows Media Player", get_wmp_info, 0 },
 	{ "iTunes", get_itunes_info, 0 },
-	{ "Messenger compatible" , get_msn_compat_info, get_msn_compat_pref },
+	{ "Messenger compatible interface" , get_msn_compat_info, get_msn_compat_pref },
 	{ "Foobar2000", get_foobar2000_info, 0 },
 #endif
 	{ "MPD", get_mpd_info, get_mpd_pref },
- 	{ "Last.fm", get_lastfm_info, get_lastfm_pref },
+ 	{ "Last.fm (API 2.0)", get_lastfm_ws_info, get_lastfm_ws_pref },
+ 	{ "Last.fm (API 1.0)", get_lastfm_info, get_lastfm_pref },
 	{ "", 0, 0 } // dummy to end the array
 };
 
@@ -186,6 +153,10 @@ trackinfo_changed(const struct TrackInfo* one, const struct TrackInfo* two)
   if ((one == NULL) && (two == NULL))
     return FALSE;
 
+  // a null trackinfo is stored in mostrecent_ti as a PLAYER_STATUS_CLOSED one...
+  if ((one == NULL) && (two != NULL) && (two->status <= PLAYER_STATUS_CLOSED))
+    return FALSE;
+
   if ((one == NULL) || (two == NULL))
     return TRUE;
 
@@ -210,7 +181,7 @@ trackinfo_changed(const struct TrackInfo* one, const struct TrackInfo* two)
 //--------------------------------------------------------------------
 
 static
-char* generate_status(const char *src, struct TrackInfo *ti)
+char* generate_status(const char *src, struct TrackInfo *ti, const char *savedstatus)
 {
 	trace("Status format: %s", src);
 
@@ -247,6 +218,9 @@ char* generate_status(const char *src, struct TrackInfo *ti)
         // Music symbol: U+266B 'beamed eighth notes'
 	status = put_field(status, 'm', "\u266b");
 
+        // The status message selected through the UI
+        status = put_field(status, 's', savedstatus);
+
 	trace("Formatted status: %s", status);
 
         return status;
@@ -267,7 +241,7 @@ set_status_tune (PurpleAccount *account, gboolean validStatus, struct TrackInfo
 	{
 		if (ti == NULL)
 			return FALSE;
-		active = (ti->status == STATUS_NORMAL) || (ti->status == STATUS_PAUSED);
+		active = (ti->status == PLAYER_STATUS_PLAYING);
 	}
 	else
 	{		
@@ -279,7 +253,7 @@ set_status_tune (PurpleAccount *account, gboolean validStatus, struct TrackInfo
 	status = purple_presence_get_status(presence, purple_primitive_get_id_from_type(PURPLE_STATUS_TUNE));
 	if (status == NULL)
 	{
-		trace("Can't get status tune for account %s, protocol %s, falling back to setting status message", 
+		trace("No tune status for account %s, protocol %s, falling back to setting status message", 
                       purple_account_get_username(account), purple_account_get_protocol_name(account));
 		return FALSE;
 	}
@@ -291,13 +265,15 @@ set_status_tune (PurpleAccount *account, gboolean validStatus, struct TrackInfo
         // this is particularly a problem for googletalk, which really expects tune info
         // to replace the status message, and lots of peopple use...
         //
-	char buf[100];
-	build_pref(buf, PREF_BROKEN_NOWLISTENING, 
-			purple_account_get_username(account),
-			purple_account_get_protocol_name(account));
-	if (purple_prefs_get_bool(buf))
+	char *buf = build_pref(PREF_BROKEN_NOWLISTENING,
+                               purple_account_get_username(account),
+                               purple_account_get_protocol_name(account));
+        gboolean dont_use_tune_status = purple_prefs_get_bool(buf);
+        g_free(buf);
+
+	if (dont_use_tune_status)
           {
-            trace("Won't try to use status tune on account '%s' protocol '%s', I've been told it's broken", purple_account_get_username(account), purple_account_get_protocol_name(account));
+            trace("Won't try to use status tune on account '%s' protocol '%s', I've been told not to", purple_account_get_username(account), purple_account_get_protocol_name(account));
             return FALSE;
           }
 
@@ -333,6 +309,7 @@ set_status_tune (PurpleAccount *account, gboolean validStatus, struct TrackInfo
                 // sets the changed flag, making this call non-idempotent (in the sense that it may
                 // cause protocol to do all the work of sending the status again, even though it
                 // hasn't actually changed).  Explicitly resetting the attributes works around that...
+                // (See http://developer.pidgin.im/ticket/7081)
                 GList *attrs = NULL;
                 attrs = g_list_append(attrs, PURPLE_TUNE_ARTIST);
                 attrs = g_list_append(attrs, 0);
@@ -342,6 +319,18 @@ set_status_tune (PurpleAccount *account, gboolean validStatus, struct TrackInfo
                 attrs = g_list_append(attrs, 0);
                 attrs = g_list_append(attrs, PURPLE_TUNE_TIME);
                 attrs = g_list_append(attrs, 0);
+                attrs = g_list_append(attrs, PURPLE_TUNE_GENRE);
+                attrs = g_list_append(attrs, 0);
+                attrs = g_list_append(attrs, PURPLE_TUNE_COMMENT);
+                attrs = g_list_append(attrs, 0);
+                attrs = g_list_append(attrs, PURPLE_TUNE_TRACK);
+                attrs = g_list_append(attrs, 0);
+                attrs = g_list_append(attrs, PURPLE_TUNE_YEAR);
+                attrs = g_list_append(attrs, 0);
+                attrs = g_list_append(attrs, PURPLE_TUNE_URL);
+                attrs = g_list_append(attrs, 0);
+                attrs = g_list_append(attrs, PURPLE_TUNE_FULL);
+                attrs = g_list_append(attrs, 0);
                 purple_status_set_active_with_attrs_list(status, FALSE, attrs);
                 g_list_free(attrs);
 	}
@@ -352,113 +341,140 @@ set_status_tune (PurpleAccount *account, gboolean validStatus, struct TrackInfo
 //--------------------------------------------------------------------
 
 gboolean
-set_status (PurpleAccount *account, char *text, struct TrackInfo *ti)
+set_status (PurpleAccount *account, struct TrackInfo *ti)
 {
-	PurpleStatus				*status			= NULL;
-	gboolean				b				= FALSE;
-
-	// check for protocol status format override
-	char buf[100];
-	gboolean overriden = FALSE;
-	const char *override;
-
-	build_pref(buf, PREF_CUSTOM_DISABLED, 
+        // check for status changing disabled for this account
+        char *buf = build_pref(PREF_CUSTOM_DISABLED,
 			purple_account_get_username(account),
 			purple_account_get_protocol_name(account));
-	if (purple_prefs_get_bool(buf)) {
-		trace("Status changing disabled for %s account", purple_account_get_username(account));
-		return TRUE;
-	}
+        gboolean status_changing_disabled = purple_prefs_get_bool(buf);
+        g_free(buf);
 
-	build_pref(buf, PREF_CUSTOM_FORMAT, 
-			purple_account_get_username(account),
-			purple_account_get_protocol_name(account));
-	override = purple_prefs_get_string(buf);
-	if (ti && (ti->status == STATUS_NORMAL) && override && (*override != 0)) {
-		text = generate_status(override, ti);
-		overriden = TRUE;
-	}
-
-        // set 'now playing' status
-        if (set_status_tune(account, *text != 0, ti) && purple_prefs_get_bool(PREF_NOW_LISTENING_ONLY))
+	if (status_changing_disabled)
           {
-            if (overriden)
-              free(text);
+            trace("Status changing disabled for %s account", purple_account_get_username(account));
             return TRUE;
           }
 
-        const char *status_text = text;
-        
-        // if the status is empty, use the current status selected through the UI (if there is one)
-        if (strlen(text) == 0)
+        // set 'now playing' status
+        if (set_status_tune(account, ti != 0, ti) && purple_prefs_get_bool(PREF_NOW_LISTENING_ONLY))
           {
-            PurpleSavedStatus *savedstatus = purple_savedstatus_get_current();
-            if (savedstatus)
-              {
-                const char *savedmessage = 0;
-                PurpleSavedStatusSub *savedsubstatus = purple_savedstatus_get_substatus(savedstatus, account);
-                if (savedsubstatus)
-                  {
-                    // use account-specific saved status
-                    savedmessage = purple_savedstatus_substatus_get_message(savedsubstatus);
-                  }
-                else
-                  {
-                    // don't have an account-specific saved status, use the general one
-                    savedmessage = purple_savedstatus_get_message(savedstatus);
-                  }
-
-                if (savedmessage != 0)
-                  {
-                    trace("empty player status, using current saved status....");
-                    status_text = savedmessage;
-                  }
-              }
+            return TRUE;
           }
 
         // have we requested 'away' status to take priority?
-	status = purple_account_get_active_status (account);
-
+	PurpleStatus *status = purple_account_get_active_status (account);
 	if (status != NULL)
 	{
           if (purple_prefs_get_bool(PREF_DISABLE_WHEN_AWAY) && purple_status_is_away(status))
             {
               trace("Status is away and we are disabled when away");
-              b = FALSE;
+              return TRUE;
             }
-          else
-            b = TRUE;
 	}
-	else
-		b	= FALSE;
+
+        // discover the pidgin saved status in use for this account
+        const char *savedmessage = "";
+        {
+          PurpleSavedStatus *savedstatus = purple_savedstatus_get_current();
+          if (savedstatus)
+            {
+              PurpleSavedStatusSub *savedsubstatus = purple_savedstatus_get_substatus(savedstatus, account);
+              if (savedsubstatus)
+                {
+                  // use account-specific saved status
+                  savedmessage = purple_savedstatus_substatus_get_message(savedsubstatus);
+                }
+              else
+                {
+                  // don't have an account-specific saved status, use the general one
+                  savedmessage = purple_savedstatus_get_message(savedstatus);
+                }
+            }
+        }
+
+        char *text = 0;
+        if (ti)
+          {
+            switch (ti->status)
+              {
+              case PLAYER_STATUS_CLOSED:
+                text = generate_status("", ti, savedmessage);
+                break;
+
+              case PLAYER_STATUS_STOPPED:
+                text = generate_status(purple_prefs_get_string(PREF_OFF), ti, savedmessage);
+                break;
+
+              case PLAYER_STATUS_PAUSED:
+                text = generate_status(purple_prefs_get_string(PREF_PAUSED), ti, savedmessage);
+                break;
+
+              case PLAYER_STATUS_PLAYING:
+                {
+                  // check for protocol status format override for this account
+                  buf = build_pref(PREF_CUSTOM_FORMAT,
+                                   purple_account_get_username(account),
+                                   purple_account_get_protocol_name(account));
+                  const char *override = purple_prefs_get_string(buf);
+                  g_free(buf);
+
+                  if (override && (*override != 0))
+                    {
+                      // if so, use account specific status format
+                      text = generate_status(override, ti, savedmessage);
+                    }
+                  else
+                    {
+                      // otherwise, use the general status format
+                      text = generate_status(purple_prefs_get_string(PREF_FORMAT), ti, savedmessage);
+                    }
+                }
+                break;
+
+              default:
+                trace("unknown player status %d", ti->status);
+              }
+          }
+
+        // ensure we have something!
+        if (text == 0)
+          text = strdup("");
+
+        // if the status is empty, use the current status selected through the UI (if there is one)
+        if (strlen(text) == 0)
+          {
+            if (savedmessage != 0)
+              {
+                trace("empty player status, using current saved status....");
+                free(text);
+                text = strdup(savedmessage);
+              }
+          }
 
         // set the status message
-	if (b)
-	{
-                if (purple_status_supports_attr (status, "message"))
-		{
-			if ((status_text != NULL) && message_changed(status_text, purple_status_get_attr_string(status, "message")))
-			{
-				trace("Setting %s status to: %s", purple_account_get_username (account), status_text);
-                                GList *attrs = NULL;
-                                attrs = g_list_append(attrs, "message");
-                                attrs = g_list_append(attrs, (gpointer)status_text);
-                                purple_status_set_active_with_attrs_list(status, TRUE, attrs);
-                                g_list_free(attrs);
-                                
-			}
-		}
-	}
+	if (purple_status_supports_attr (status, "message"))
+          {
+            if ((text != NULL) && message_changed(text, purple_status_get_attr_string(status, "message")))
+              {
+                trace("Setting %s status to: %s", purple_account_get_username (account), text);
+                GList *attrs = NULL;
+                attrs = g_list_append(attrs, "message");
+                attrs = g_list_append(attrs, (gpointer)text);
+                purple_status_set_active_with_attrs_list(status, TRUE, attrs);
+                g_list_free(attrs);
+              }
+          }
 
-	if (overriden)
-		free(text);
+        free(text);
 	return TRUE;
 }
 
 //--------------------------------------------------------------------
 
+static
 void
-set_userstatus_for_active_accounts (char *userstatus, struct TrackInfo *ti)
+set_userstatus_for_active_accounts (struct TrackInfo *ti)
 {
         GList                   *accounts               = NULL,
                                         *head                   = NULL;
@@ -466,7 +482,7 @@ set_userstatus_for_active_accounts (char *userstatus, struct TrackInfo *ti)
 
 	gboolean b = purple_prefs_get_bool(PREF_DISABLED);
 	if (b) {
-		trace("Disabled flag on!");
+		trace("status changing has been disabled");
 	}
         else
           {
@@ -477,7 +493,7 @@ set_userstatus_for_active_accounts (char *userstatus, struct TrackInfo *ti)
                 account = (PurpleAccount *)accounts->data;
                 
                 if (account != NULL)
-                  set_status (account, userstatus, ti);
+                  set_status (account, ti);
                 
                 accounts = accounts->next;
               }
@@ -491,6 +507,8 @@ set_userstatus_for_active_accounts (char *userstatus, struct TrackInfo *ti)
         // stash trackinfo in case we need it elsewhere....
         if (ti)
           mostrecent_ti = *ti;
+        else
+          mostrecent_ti.status = PLAYER_STATUS_CLOSED;
 }
 
 //--------------------------------------------------------------------
@@ -525,35 +543,78 @@ static void utf8_validate(char* text)
 
 //--------------------------------------------------------------------
 
+static
+void
+set_track_information(struct TrackInfo *ti)
+{
+  set_userstatus_for_active_accounts(ti);
+}
+
+//--------------------------------------------------------------------
+
+void
+restore_track_information(void)
+{
+  set_track_information(&mostrecent_ti);
+}
+
+//--------------------------------------------------------------------
+
+void
+clear_track_information(void)
+{
+  set_userstatus_for_active_accounts(0);
+}
+
+//--------------------------------------------------------------------
+
 static gboolean
 cb_timeout(gpointer data) {
 	if (g_run == 0)
 		return FALSE;
 
-        gboolean b = TRUE;
-
 	struct TrackInfo ti;
-	memset(&ti, 0, sizeof(ti));
-	ti.status = STATUS_OFF;
+
 	int player = purple_prefs_get_int(PREF_PLAYER);
 
-	if (player != -1) {
-                ti.player = g_players[player].name;
-		b = (*g_players[player].track_func)(&ti);
-	} else {
-		int i = 0;
-		while (strlen(g_players[i].name) && (!b || ti.status == STATUS_OFF)) {
-                        ti.player = g_players[i].name;
-			b = (*g_players[i].track_func)(&ti);
-			++i;
-		}
-	}
+	if (player != -1)
+          {
+            // a specific player is configured
+            trace("trying '%s'", g_players[player].name);
+            memset(&ti, 0, sizeof(ti));
+            ti.status = PLAYER_STATUS_CLOSED;
+            ti.player = g_players[player].name;
+            (*g_players[player].track_func)(&ti);
+          }
+        else
+          {
+            // try to autodetect an active player
+            int i = 0;
+            while (strlen(g_players[i].name))
+              {
+                trace("trying '%s'", g_players[i].name);
+                memset(&ti, 0, sizeof(ti));
+                ti.status = PLAYER_STATUS_CLOSED;
+                ti.player = g_players[i].name;
+                (*g_players[i].track_func)(&ti);
 
-	if (!b) {
+                // XXX: to maintain historical behaviour we stop looking at the first player which is paused or playing
+                // we could try harder and continue to look for a player which is playing if we found one which was paused...
+                if (ti.status > PLAYER_STATUS_STOPPED)
+                  {
+                    break;
+                  }
+
+                ++i;
+            }
+          }
+
+	if (ti.status == PLAYER_STATUS_CLOSED)
+          {
 		trace("Getting info failed. Setting empty status.");
-		set_userstatus_for_active_accounts("", 0);
+		set_userstatus_for_active_accounts(0);
 		return TRUE;
-	}
+          }
 
 	trim(ti.album);
 	trim(ti.track);
@@ -573,37 +634,19 @@ cb_timeout(gpointer data) {
             filter(ti.album);
 	}
 
-	char *status = NULL;
-	switch (ti.status) {
-		case STATUS_OFF:
-			status = generate_status(purple_prefs_get_string(PREF_OFF), &ti);
-			break;
-		case STATUS_PAUSED:
-			status = generate_status(purple_prefs_get_string(PREF_PAUSED), &ti);
-			break;
-		case STATUS_NORMAL:
-			status = generate_status(purple_prefs_get_string(PREF_FORMAT), &ti);
-			break;
-		default:
-                  trace("unknown player status %d", ti.status);
-	}
-
-        if (status)
-          {
-            set_userstatus_for_active_accounts(status, &ti);
-            free(status);
-          }
+        set_track_information(&ti);
 
 	return TRUE;
 }
 
 //--------------------------------------------------------------------
 
+static
 PurpleCmdRet musictracker_cmd_nowplaying(PurpleConversation *conv, const gchar *cmd, gchar **args, gchar **error, void *data)
 {
-  if (mostrecent_ti.status == STATUS_NORMAL)
+  if (mostrecent_ti.status == PLAYER_STATUS_PLAYING)
     {
-      char *status = generate_status(purple_prefs_get_string(PREF_FORMAT), &mostrecent_ti);
+      char *status = generate_status(purple_prefs_get_string(PREF_FORMAT), &mostrecent_ti, "");
       PurpleConversationType type = purple_conversation_get_type (conv);
   
       if (type == PURPLE_CONV_TYPE_CHAT)
@@ -631,30 +674,39 @@ PurpleCmdRet musictracker_cmd_nowplaying(PurpleConversation *conv, const gchar *
 
 static gboolean
 plugin_load(PurplePlugin *plugin) {
-	trace("Plugin loaded.");
+	trace("Plugin loading.");
 	g_tid = purple_timeout_add(INTERVAL, &cb_timeout, 0);
-	g_plugin = plugin;
+
+        // make the mostrecent track information something invalid so it will always get updated the first time...
+        mostrecent_ti.status = PLAYER_STATUS_INVALID;
+	mostrecent_ti.player = "";
 
 	// custom status format for each account
 	GList *accounts = purple_accounts_get_all();
 	while (accounts) {
 		PurpleAccount *account = (PurpleAccount*) accounts->data;
-		char buf[100];
-		build_pref(buf, PREF_CUSTOM_FORMAT, 
-					purple_account_get_username(account),
-					purple_account_get_protocol_name(account));
+                trace("Checking if we need to set default preferences for %s on protocol %s", purple_account_get_username(account),
+                      purple_account_get_protocol_name(account));
+
+		char *buf = build_pref(PREF_CUSTOM_FORMAT,
+                                       purple_account_get_username(account),
+                                       purple_account_get_protocol_name(account));
 		if (!purple_prefs_exists(buf)) {
 			purple_prefs_add_string(buf, "");
 		}
-		build_pref(buf, PREF_CUSTOM_DISABLED, 
-					purple_account_get_username(account),
-					purple_account_get_protocol_name(account));
+                g_free(buf);
+
+		buf = build_pref(PREF_CUSTOM_DISABLED,
+                                 purple_account_get_username(account),
+                                 purple_account_get_protocol_name(account));
 		if (!purple_prefs_exists(buf)) {
 			purple_prefs_add_bool(buf, FALSE);
 		}
-		build_pref(buf, PREF_BROKEN_NOWLISTENING, 
-					purple_account_get_username(account),
-					purple_account_get_protocol_name(account));
+                g_free(buf);
+
+		buf = build_pref(PREF_BROKEN_NOWLISTENING,
+                                 purple_account_get_username(account),
+                                 purple_account_get_protocol_name(account));
 		if (!purple_prefs_exists(buf)) {
                         // use a crude guess for the initial state of the broken now listening flag...
                         // there's no good way to do this automatically, hence the reason for offloading
@@ -668,11 +720,13 @@ plugin_load(PurplePlugin *plugin) {
                             purple_prefs_add_bool(buf, FALSE);
                           }
 		}
+                g_free(buf);
 
 		accounts = accounts->next;
 	}
 
         // register the 'nowplaying' commmand
+	trace("Registering nowplaying command.");
         cmdid_nowplaying = purple_cmd_register("nowplaying",
                             "", 
                             PURPLE_CMD_P_DEFAULT,
@@ -692,6 +746,7 @@ plugin_load(PurplePlugin *plugin) {
                             NULL);
 
 	g_run = 1;
+	trace("Plugin loaded.");
     return TRUE;
 }
 
@@ -700,7 +755,7 @@ plugin_load(PurplePlugin *plugin) {
 static gboolean
 plugin_unload(PurplePlugin *plugin) {
 	trace("Plugin unloaded.");
-        set_userstatus_for_active_accounts("", 0);
+        set_userstatus_for_active_accounts(0);
 	g_run = 0;
         purple_cmd_unregister(cmdid_nowplaying);
         purple_cmd_unregister(cmdid_np);
@@ -726,7 +781,7 @@ static PurplePluginInfo info = {
     NULL,
     PURPLE_PRIORITY_DEFAULT,
 
-    PLUGIN_ID,
+    "gtk-jturney-musictracker",
     "MusicTracker",
     VERSION,
 
@@ -790,11 +845,35 @@ init_plugin(PurplePlugin *plugin) {
 #ifdef ENABLE_NLS
         // bind translation domain for musictracker to file
         bindtextdomain(PACKAGE, LOCALEDIR);
+        // always output in UTF-8 codeset as that is used internally by GTK+
+	bind_textdomain_codeset(PACKAGE, "UTF-8");
 #endif /* ENABLE_NLS */
 
         // initialize translated plugin details
+        /* 
+           TRANSLATORS: this string controls the name musictracker appears as under the Tools menu
+           It's probably a good idea to treat 'MusicTracker' as a proper name, transliterate but don't translate
+         */
+        info.name        = _("MusicTracker");
         info.summary     = _("MusicTracker Plugin for Pidgin");
-        info.description = _("The MusicTracker Plugin allows you to customize your status message with information about currently playing song from your music player. Portions initially adopted from pidgin-currenttrack project.");
+
+        /*
+           TRANSLATORS: %s will be replaced with the URL of the translation site, currently
+           http://translations.launchpad.net/pidgin-musictracker/trunk/+pots/musictracker
+         */
+        char *translation_bugs = g_strdup_printf(_("Fix translation bugs at %s"),
+                                                 "http://translations.launchpad.net/pidgin-musictracker/trunk/+pots/musictracker");
+
+        info.description = g_strdup_printf("%s\n%s\n%s",
+                                           _("The MusicTracker Plugin allows you to customize your status message with information about currently playing song from your music player. Portions initially adopted from pidgin-currenttrack project."),
+#ifdef WIN32
+                                           _("WMP support via WMPuICE by Christian Mueller from http://www.mediatexx.com."),
+#else
+                                           "",
+#endif
+                                           translation_bugs);
+
+        g_free(translation_bugs);
 }
 
 //--------------------------------------------------------------------
