@@ -15,7 +15,7 @@ int readline(FILE* file, char *buf, int len);
 const char *parse_value(const char *line, const char* key);
 char *put_field(char *buf, char identifier, const char *field);
 void trim(char *buf);
-void build_pref(char *dest, const char *format, const char* str1, const char* str2);
+char *build_pref(const char *format, const char* str1, const char* str2);
 
 pcre* regex(const char* pattern, int options);
 int capture(pcre* re, const char *text, int len, ...);
